# Helper Tools

Mapilio Helper Tools is a python library for some math, prediction and handler functions

[![Actions Status](https://github.com/mapilio/helper-tools/workflows/main/badge.svg)](https://github.com/mapilio/helper-tools/actions)
